@@ -92,33 +92,6 @@ struct D3D12StateObjectInfo;
 struct D3D12ResourceInfo;
 struct D3D12CommandSignatureInfo;
 
-// Util function for getting the extra info object from a DxObjectInfo.
-template <typename T>
-T* GetExtraInfo(DxObjectInfo* info)
-{
-    if ((info != nullptr) && (info->extra_info != nullptr) && (info->extra_info->extra_info_type == T::kType))
-    {
-        return static_cast<T*>(info->extra_info.get());
-    }
-
-    GFXRECON_LOG_FATAL("%s object does not have an associated info structure", T::kObjectType);
-
-    return nullptr;
-}
-
-template <typename T>
-const T* GetExtraInfo(const DxObjectInfo* info)
-{
-    if ((info != nullptr) && (info->extra_info != nullptr) && (info->extra_info->extra_info_type == T::kType))
-    {
-        return static_cast<T*>(info->extra_info.get());
-    }
-
-    GFXRECON_LOG_FATAL("%s object does not have an associated info structure", T::kObjectType);
-
-    return nullptr;
-}
-
 struct MappedMemoryInfo
 {
     uint32_t count{ 0 };     ///< Number of times that the memory has been mapped.
@@ -182,18 +155,21 @@ struct ResourceValueInfo
     uint64_t                size{ 0 };
     D3D12StateObjectInfo*   state_object{ nullptr }; ///< Used to map values in shader records.
     ArgumentBufferExtraInfo arg_buffer_extra_info;
+    uint32_t                max_command_count{ 0 };
 
     ResourceValueInfo(uint64_t                in_offset,
                       ResourceValueType       in_type,
                       uint64_t                in_size,
                       D3D12StateObjectInfo*   in_state_object,
-                      ArgumentBufferExtraInfo in_arg_buffer_extra_info)
+                      ArgumentBufferExtraInfo in_arg_buffer_extra_info,
+                      uint32_t                in_max_command_count)
     {
         offset                = in_offset;
         type                  = in_type;
         size                  = in_size;
         state_object          = in_state_object;
         arg_buffer_extra_info = in_arg_buffer_extra_info;
+        max_command_count     = in_max_command_count;
     }
 
     bool operator<(const ResourceValueInfo& other) const { return offset < other.offset; }
@@ -220,6 +196,33 @@ struct DxObjectInfo
     std::unordered_map<VariableLengthArrayIndices, size_t> array_counts;
 };
 
+// Util function for getting the extra info object from a DxObjectInfo.
+template <typename T>
+T* GetExtraInfo(DxObjectInfo* info)
+{
+    if ((info != nullptr) && (info->extra_info != nullptr) && (info->extra_info->extra_info_type == T::kType))
+    {
+        return static_cast<T*>(info->extra_info.get());
+    }
+
+    GFXRECON_LOG_FATAL("%s object does not have an associated info structure", T::kObjectType);
+
+    return nullptr;
+}
+
+template <typename T>
+const T* GetExtraInfo(const DxObjectInfo* info)
+{
+    if ((info != nullptr) && (info->extra_info != nullptr) && (info->extra_info->extra_info_type == T::kType))
+    {
+        return static_cast<T*>(info->extra_info.get());
+    }
+
+    GFXRECON_LOG_FATAL("%s object does not have an associated info structure", T::kObjectType);
+
+    return nullptr;
+}
+
 struct DxgiSwapchainInfo : DxObjectExtraInfo
 {
     static constexpr DxObjectInfoType kType         = DxObjectInfoType::kIDxgiSwapchainInfo;
@@ -236,7 +239,7 @@ struct DxgiSwapchainInfo : DxObjectExtraInfo
 
     graphics::dx12::ID3D12CommandQueueComPtr command_queue{
         nullptr
-    };                           ///< The command queue that was used to create the swapchain.
+    }; ///< The command queue that was used to create the swapchain.
     bool is_fullscreen{ false }; ///< Swapchain full screen flag.
 };
 
