@@ -380,7 +380,7 @@ bool FileTransformer::ReadCompressedParameterBuffer(size_t  compressed_buffer_si
         size_t uncompressed_size = compressor_->Decompress(compressed_buffer_size,
                                                            compressed_parameter_buffer_.data(),
                                                            expected_uncompressed_size,
-                                                           &parameter_buffer_);
+                                                           parameter_buffer_.data());
         if ((0 < uncompressed_size) && (uncompressed_size == expected_uncompressed_size))
         {
             *uncompressed_buffer_size = uncompressed_size;
