@@ -88,6 +88,7 @@ enum PhysicalDeviceArrayIndices : uint32_t
     kShaderEXTArrayGetShaderBinaryDataEXT                                                = 21,
     kPhysicalDeviceArrayGetPhysicalDeviceCooperativeMatrixFlexibleDimensionsPropertiesNV = 22,
     kPhysicalDeviceArrayGetPhysicalDeviceCooperativeVectorPropertiesNV                   = 23,
+    kPhysicalDeviceArrayEnumeratePhysicalDeviceQueueFamilyPerformanceCountersByRegionARM = 24,
 
     // Aliases for extensions functions that were promoted to core.
     kPhysicalDeviceArrayGetPhysicalDeviceQueueFamilyProperties2KHR =
@@ -414,7 +415,7 @@ struct VulkanBufferInfo : public VulkanObjectInfo<VkBuffer>
     VkDeviceSize       size{ 0 };
     uint32_t           queue_family_index{ 0 };
 
-    // map acceleration-structure capture-addresses to existing (alias) AS-handles
+    // map acceleration-structure replay-addresses to existing (alias) AS-handles
     std::unordered_map<VkDeviceAddress, std::unordered_set<const VulkanAccelerationStructureKHRInfo*>>
         acceleration_structures;
 };
@@ -715,26 +716,6 @@ struct VulkanDescriptorTypeBufferInfo
     VkDeviceSize            range;
 };
 
-struct VulkanDescriptorSetBindingInfo
-{
-    VkDescriptorType   desc_type{ VK_DESCRIPTOR_TYPE_MAX_ENUM };
-    VkShaderStageFlags stage_flags{ 0 };
-
-    // Use a map to represent array as many entries can be left unpopulated.
-    // Use a sorted map so that array indices are printed in order in the json output
-    std::map<uint32_t, VulkanDescriptorTypeImageInfo>  image_info;
-    std::map<uint32_t, VulkanDescriptorTypeBufferInfo> buffer_info;
-    std::map<uint32_t, const VulkanBufferViewInfo*>    texel_buffer_view_info;
-    std::vector<uint8_t>                               inline_uniform_block;
-};
-
-struct VulkanDescriptorSetInfo : public VulkanPoolObjectInfo<VkDescriptorSet>
-{
-    // One entry per binding
-    using VulkanDescriptorBindingsInfo = std::unordered_map<uint32_t, VulkanDescriptorSetBindingInfo>;
-    VulkanDescriptorBindingsInfo descriptors;
-};
-
 struct VulkanAccelerationStructureKHRInfo : public VulkanObjectInfo<VkAccelerationStructureKHR>
 {
     VkDeviceAddress capture_address = 0;
@@ -757,6 +738,27 @@ struct VulkanAccelerationStructureNVInfo : public VulkanObjectInfo<VkAcceleratio
     VkMemoryPropertyFlags memory_property_flags{ 0 };
 };
 
+struct VulkanDescriptorSetBindingInfo
+{
+    VkDescriptorType   desc_type{ VK_DESCRIPTOR_TYPE_MAX_ENUM };
+    VkShaderStageFlags stage_flags{ 0 };
+
+    // Use a map to represent array as many entries can be left unpopulated.
+    // Use a sorted map so that array indices are printed in order in the json output
+    std::map<uint32_t, VulkanDescriptorTypeImageInfo>             image_info;
+    std::map<uint32_t, VulkanDescriptorTypeBufferInfo>            buffer_info;
+    std::map<uint32_t, const VulkanBufferViewInfo*>               texel_buffer_view_info;
+    std::map<uint32_t, const VulkanAccelerationStructureKHRInfo*> acceleration_structs_khr_info;
+    std::vector<uint8_t>                                          inline_uniform_block;
+};
+
+struct VulkanDescriptorSetInfo : public VulkanPoolObjectInfo<VkDescriptorSet>
+{
+    // One entry per binding
+    using VulkanDescriptorBindingsInfo = std::unordered_map<uint32_t, VulkanDescriptorSetBindingInfo>;
+    VulkanDescriptorBindingsInfo descriptors;
+};
+
 //
 // Handle alias types for extension handle types that have been promoted to core types.
 //
