@@ -24,6 +24,7 @@
 #define GFXRECON_GENERATED_VULKAN_REPLAY_DUMP_RESOURCES_DRAW_CALLS_H
 
 #include "decode/common_object_info_table.h"
+#include "decode/vulkan_device_address_tracker.h"
 #include "decode/vulkan_replay_dump_resources_common.h"
 #include "decode/vulkan_object_info.h"
 #include "decode/vulkan_replay_options.h"
@@ -61,16 +62,19 @@ class DrawCallsDumpingContext
         kDrawIndexedIndirectCountAMD
     };
 
-    DrawCallsDumpingContext(const DrawCallIndices*       dc_indices_,
-                            const RenderPassIndices*     rp_indices,
-                            CommonObjectInfoTable&       object_info_table,
-                            const VulkanReplayOptions&   options,
-                            VulkanDumpResourcesDelegate& delegate,
-                            const util::Compressor*      compressor);
+    DrawCallsDumpingContext(const CommandIndices*                       dc_indices,
+                            const RenderPassIndices*                    rp_indices,
+                            const CommandImageSubresource&              dc_subresources,
+                            CommonObjectInfoTable&                      object_info_table,
+                            const VulkanReplayOptions&                  options,
+                            VulkanDumpResourcesDelegate&                delegate,
+                            const util::Compressor*                     compressor,
+                            DumpResourcesAccelerationStructuresContext& acceleration_structures_context,
+                            const VulkanPerDeviceAddressTrackers&       address_trackers);
 
     ~DrawCallsDumpingContext();
 
-    bool IsRecording() const { return current_cb_index_ < command_buffers_.size(); }
+    bool IsRecording() const { return recording_; }
 
     bool MustDumpDrawCall(uint64_t index) const;
 
@@ -86,7 +90,7 @@ class DrawCallsDumpingContext
 
     void BindPipeline(VkPipelineBindPoint bind_point, const VulkanPipelineInfo* pipeline);
 
-    VkResult CloneCommandBuffer(VulkanCommandBufferInfo*             orig_cmd_buf_info,
+    VkResult BeginCommandBuffer(VulkanCommandBufferInfo*             orig_cmd_buf_info,
                                 const graphics::VulkanDeviceTable*   dev_table,
                                 const graphics::VulkanInstanceTable* inst_table,
                                 const VkCommandBufferBeginInfo*      begin_info);
@@ -195,6 +199,8 @@ class DrawCallsDumpingContext
 
     void UpdateSecondaries();
 
+    void MergeRenderPasses(const DrawCallsDumpingContext& secondary_context);
+
   private:
     void SetRenderTargets(const std::vector<VulkanImageInfo*>& color_att_imgs,
                           VulkanImageInfo*                     depth_att_img,
@@ -223,8 +229,9 @@ class DrawCallsDumpingContext
     VulkanCommandBufferInfo*     original_command_buffer_info_;
     std::vector<VkCommandBuffer> command_buffers_;
     size_t                       current_cb_index_;
-    DrawCallIndices              dc_indices_;
+    CommandIndices               dc_indices_;
     RenderPassIndices            RP_indices_;
+    CommandImageSubresource      dc_subresources_;
     const VulkanRenderPassInfo*  active_renderpass_;
     const VulkanFramebufferInfo* active_framebuffer_;
     const VulkanPipelineInfo*    bound_gr_pipeline_;
@@ -233,6 +240,7 @@ class DrawCallsDumpingContext
     VulkanDumpResourcesDelegate& delegate_;
     const VulkanReplayOptions&   options_;
     const util::Compressor*      compressor_;
+    bool                         secondary_with_dynamic_rendering_;
 
     // Execute commands block index : DrawCallContexts
     std::unordered_map<uint64_t, std::vector<DrawCallsDumpingContext*>> secondaries_;
@@ -255,7 +263,7 @@ class DrawCallsDumpingContext
         VkImageLayout              depth_attachment_layout{ VK_IMAGE_LAYOUT_GENERAL };
     };
 
-    std::unordered_map<uint32_t, RenderPassAttachmentLayouts> dynamic_rendering_attachment_layouts_;
+    std::unordered_map<uint32_t, RenderPassAttachmentLayouts> rendering_attachment_layouts_;
 
   public:
     struct RenderTargets
@@ -663,9 +671,9 @@ class DrawCallsDumpingContext
     using DrawCallParameters = std::unordered_map<uint64_t, std::unique_ptr<DrawCallParams>>;
     DrawCallParameters draw_call_params_;
 
-    DrawCallParameters&    GetDrawCallParameters() { return draw_call_params_; }
-    DrawCallIndices&       GetDrawCallIndices() { return dc_indices_; }
-    const DrawCallIndices& GetDrawCallIndices() const { return dc_indices_; }
+    DrawCallParameters&   GetDrawCallParameters() { return draw_call_params_; }
+    CommandIndices&       GetDrawCallIndices() { return dc_indices_; }
+    const CommandIndices& GetDrawCallIndices() const { return dc_indices_; }
 
     struct
     {
@@ -683,8 +691,9 @@ class DrawCallsDumpingContext
     // multiple times
     struct RenderPassDumpedDescriptors
     {
-        std::unordered_map<const VulkanImageInfo*, const DumpedImage&>   image_descriptors;
-        std::unordered_map<const VulkanBufferInfo*, const DumpedBuffer&> buffer_descriptors;
+        std::map<DescriptorLocation, const DumpedImage&>                         image_descriptors;
+        std::map<DescriptorLocation, const DumpedBuffer&>                        buffer_descriptors;
+        std::map<DescriptorLocation, const DumpedTopLevelAccelerationStructure&> acceleration_structures;
     };
 
     std::vector<RenderPassDumpedDescriptors> render_pass_dumped_descriptors_;
@@ -693,11 +702,18 @@ class DrawCallsDumpingContext
     VkFence                         aux_fence_;
     DumpResourcesCommandBufferLevel command_buffer_level_;
 
+    // recording_ will be true between the corresponding BCB and the last FinalizeCommandBuffer
+    bool recording_;
+
     const graphics::VulkanDeviceTable*      device_table_;
     const graphics::VulkanInstanceTable*    instance_table_;
     CommonObjectInfoTable&                  object_info_table_;
     const VkPhysicalDeviceMemoryProperties* replay_device_phys_mem_props_;
 
+    DumpResourcesAccelerationStructuresContext& acceleration_structures_context_;
+
+    const VulkanPerDeviceAddressTrackers& address_trackers_;
+
     void SecondaryUpdateContextFromPrimary(const VulkanPipelineInfo*     gr_pipeline,
                                            const BoundVertexBuffersInfo& vertex_buffers,
                                            const BoundIndexBuffer&       index_buffer,
