@@ -1,5 +1,5 @@
 /*
-** Copyright (c) 2024 LunarG, Inc.
+** Copyright (c) 2025 LunarG, Inc.
 **
 ** Permission is hereby granted, free of charge, to any person obtaining a
 ** copy of this software and associated documentation files (the "Software"),
@@ -21,6 +21,7 @@
 */
 
 #include "decode/vulkan_object_info.h"
+#include "decode/vulkan_replay_dump_resources_options.h"
 #include "decode/vulkan_replay_dump_resources_common.h"
 #include "format/format_util.h"
 #include "util/file_path.h"
@@ -46,22 +47,27 @@ VulkanReplayDumpResourcesJson::VulkanReplayDumpResourcesJson(const VulkanReplayO
     header_["vulkanVersion"] = std::to_string(VK_VERSION_MAJOR(VK_HEADER_VERSION_COMPLETE)) + "." +
                                std::to_string(VK_VERSION_MINOR(VK_HEADER_VERSION_COMPLETE)) + "." +
                                std::to_string(VK_VERSION_PATCH(VK_HEADER_VERSION_COMPLETE));
-    header_["gfxreconVersion"] = GFXRECON_PROJECT_VERSION_STRING;
+    header_["gfxreconVersion"] = GetProjectVersionString();
     header_["captureFile"]     = options.capture_filename;
 
-    auto& dr_options                                    = header_["dumpResourcesOptions"];
-    dr_options["scale"]                                 = options.dump_resources_scale;
-    dr_options["dumpResourcesOutputDir"]                = options.dump_resources_output_dir;
-    dr_options["dumpResourcesColorAttachmentIndex"]     = options.dump_resources_color_attachment_index;
-    dr_options["dumpResourcesBefore"]                   = options.dump_resources_before;
-    dr_options["dumpResourcesDumpDepth"]                = options.dump_resources_dump_depth;
-    dr_options["dumpResourcesDumpVertexIndexBuffer"]    = options.dump_resources_dump_vertex_index_buffer;
-    dr_options["dumpResourcesDumpImmutableResources"]   = options.dump_resources_dump_immutable_resources;
-    dr_options["dumpResourcesDumpAllImageSubresources"] = options.dump_resources_dump_all_image_subresources;
-    dr_options["dumpResourcesDumpRawImages"]            = options.dump_resources_dump_raw_images;
-    dr_options["dumpResourcesDumpSeparateAlpha"]        = options.dump_resources_dump_separate_alpha;
-    dr_options["dumpResourcesDumpUnusedVertexBindings"] = options.dump_resources_dump_unused_vertex_bindings;
-    dr_options["dumpResourcesBinaryFileCompressionType"] =
+    auto& dr_options            = header_[kVDROptions];
+    dr_options[kVDROptionScale] = options.dump_resources_scale;
+    dr_options[kVDROptionImageFormat] =
+        options.dump_resources_dump_raw_images ? "bin" : ImageFormatToString(options.dump_resources_image_format);
+    dr_options[kVDROptionOutputDir]                = options.dump_resources_output_dir;
+    dr_options[kVDROptionColorAttachmentIndex]     = options.dump_resources_color_attachment_index;
+    dr_options[kVDROptionBefore]                   = options.dump_resources_before;
+    dr_options[kVDROptionDumpDepth]                = options.dump_resources_dump_depth;
+    dr_options[kVDROptionDumpVertexIndexBuffer]    = options.dump_resources_dump_vertex_index_buffer;
+    dr_options[kVDROptionDumpAllDescriptors]       = options.dump_all_descriptors;
+    dr_options[kVDROptionDumpAllImageSubresources] = options.dump_resources_dump_all_image_subresources;
+    dr_options[kVDROptionDumpRawImages]            = options.dump_resources_dump_raw_images;
+    dr_options[kVDROptionDumpSeparateAlpha]        = options.dump_resources_dump_separate_alpha;
+    dr_options[kVDROptionDumpUnusedVertexBindings] = options.dump_resources_dump_unused_vertex_bindings;
+    dr_options[kVDROptionJsonOutputPerCommand]     = options.dump_resources_json_per_command;
+    dr_options[kVDROptionDumpBuildAccelerationStructuresInputBuffers] =
+        options.dump_resources_dump_build_AS_input_buffers;
+    dr_options[kVDROptionBinaryFileCompressionType] =
         format::GetCompressionTypeName(options.dump_resources_binary_file_compression_type);
 };
 
@@ -233,12 +239,15 @@ void VulkanReplayDumpResourcesJson::InsertBufferInfo(nlohmann::ordered_json& jso
                                                      const DumpedBuffer&     dumped_buffer)
 {
     const VulkanBufferInfo* buffer_info = dumped_buffer.buffer_info;
-    GFXRECON_ASSERT(buffer_info != nullptr);
 
-    json_entry["bufferId"] = buffer_info->capture_id;
-    json_entry["offset"]   = dumped_buffer.offset;
-    json_entry["size"]     = dumped_buffer.size;
-    json_entry["file"]     = dumped_buffer.filename;
+    if (buffer_info != nullptr)
+    {
+        json_entry["bufferId"] = buffer_info->capture_id;
+    }
+
+    json_entry["offset"] = dumped_buffer.offset;
+    json_entry["size"]   = dumped_buffer.size;
+    json_entry["file"]   = dumped_buffer.filename;
 
     if (dumped_buffer.compressed_size)
     {
@@ -249,9 +258,6 @@ void VulkanReplayDumpResourcesJson::InsertBufferInfo(nlohmann::ordered_json& jso
 void VulkanReplayDumpResourcesJson::InsertBeforeBufferInfo(nlohmann::ordered_json& json_entry,
                                                            const DumpedBuffer&     dumped_buffer)
 {
-    const VulkanBufferInfo* buffer_info = dumped_buffer.buffer_info;
-    GFXRECON_ASSERT(buffer_info != nullptr);
-
     json_entry["beforeFile"] = dumped_buffer.filename;
 
     if (dumped_buffer.compressed_size)
@@ -260,5 +266,15 @@ void VulkanReplayDumpResourcesJson::InsertBeforeBufferInfo(nlohmann::ordered_jso
     }
 }
 
+void VulkanReplayDumpResourcesJson::InsertASBuildRangeInfo(nlohmann::ordered_json&                         json_entry,
+                                                           const VkAccelerationStructureBuildRangeInfoKHR& range)
+{
+    auto& range_entry              = json_entry["VkAccelerationStructureBuildRangeInfoKHR"];
+    range_entry["primitiveCount"]  = range.primitiveCount;
+    range_entry["primitiveOffset"] = range.primitiveOffset;
+    range_entry["firstVertex"]     = range.firstVertex;
+    range_entry["transformOffset"] = range.transformOffset;
+}
+
 GFXRECON_END_NAMESPACE(gfxrecon)
 GFXRECON_END_NAMESPACE(decode)
