@@ -801,8 +801,7 @@ void Dx12StateWriter::WriteMetaCommandCreationState(const Dx12StateTable& state_
                     format::ApiFamilyId::ApiFamily_D3D12, format::MetaDataType::kInitializeMetaCommand);
                 init_meta_command.thread_id  = thread_id_;
                 init_meta_command.capture_id = wrapper->GetCaptureId();
-                init_meta_command.initialization_parameters_data_size =
-                    wrapper_info->initialize_parameters->GetDataSize();
+                init_meta_command.data_size  = wrapper_info->initialize_parameters->GetDataSize();
                 init_meta_command.total_number_of_initializemetacommand = metacommand_wrappers.size();
                 init_meta_command.block_index                           = ++block_index;
 
@@ -847,10 +846,13 @@ void Dx12StateWriter::WriteResourceSnapshots(
             begin_cmd.meta_header.block_header.type = format::kMetaDataBlock;
             begin_cmd.meta_header.meta_data_id      = format::MakeMetaDataId(
                 format::ApiFamilyId::ApiFamily_D3D12, format::MetaDataType::kBeginResourceInitCommand);
-            begin_cmd.thread_id         = thread_id_;
-            begin_cmd.device_id         = device_id;
-            begin_cmd.max_resource_size = max_resource_size;
-            begin_cmd.max_copy_size     = max_resource_size;
+            begin_cmd.thread_id       = thread_id_;
+            begin_cmd.device_id       = device_id;
+
+            // TODO: adjust to hold sum of resource-sizes
+            begin_cmd.total_copy_size = max_resource_size;
+
+            begin_cmd.max_copy_size   = max_resource_size;
 
             output_stream_->Write(&begin_cmd, sizeof(begin_cmd));
 
