@@ -126,14 +126,14 @@ uint64_t GetWrappedId(uint64_t, VkObjectType object_type);
 
 uint64_t GetWrappedId(uint64_t object, VkDebugReportObjectTypeEXT object_type);
 
-inline const VulkanInstanceTable* GetInstanceTable(VkInstance handle)
+inline const graphics::VulkanInstanceTable* GetInstanceTable(VkInstance handle)
 {
     assert(handle != VK_NULL_HANDLE);
     auto wrapper = GetWrapper<InstanceWrapper>(handle);
     return &wrapper->layer_table;
 }
 
-inline const VulkanInstanceTable* GetInstanceTable(VkPhysicalDevice handle)
+inline const graphics::VulkanInstanceTable* GetInstanceTable(VkPhysicalDevice handle)
 {
     assert(handle != VK_NULL_HANDLE);
     auto wrapper = GetWrapper<PhysicalDeviceWrapper>(handle);
@@ -141,14 +141,14 @@ inline const VulkanInstanceTable* GetInstanceTable(VkPhysicalDevice handle)
     return wrapper->layer_table_ref;
 }
 
-inline const VulkanDeviceTable* GetDeviceTable(VkDevice handle)
+inline const graphics::VulkanDeviceTable* GetDeviceTable(VkDevice handle)
 {
     assert(handle != VK_NULL_HANDLE);
     auto wrapper = GetWrapper<DeviceWrapper>(handle);
     return &wrapper->layer_table;
 }
 
-inline const VulkanDeviceTable* GetDeviceTable(VkQueue handle)
+inline const graphics::VulkanDeviceTable* GetDeviceTable(VkQueue handle)
 {
     assert(handle != VK_NULL_HANDLE);
     auto wrapper = GetWrapper<QueueWrapper>(handle);
@@ -156,7 +156,7 @@ inline const VulkanDeviceTable* GetDeviceTable(VkQueue handle)
     return wrapper->layer_table_ref;
 }
 
-inline const VulkanDeviceTable* GetDeviceTable(VkCommandBuffer handle)
+inline const graphics::VulkanDeviceTable* GetDeviceTable(VkCommandBuffer handle)
 {
     assert(handle != VK_NULL_HANDLE);
     auto wrapper = GetWrapper<CommandBufferWrapper>(handle);
@@ -460,6 +460,7 @@ inline void CreateWrappedHandle<DeviceWrapper,
         CreateWrappedNonDispatchHandle<ImageWrapper>(handle, get_id);
         wrapper                     = GetWrapper<ImageWrapper>(*handle);
         wrapper->is_swapchain_image = true;
+        wrapper->parent_swapchains.insert(parent_wrapper->handle);
         parent_wrapper->child_images.push_back(wrapper);
     }
 }
@@ -651,8 +652,16 @@ inline void DestroyWrappedHandle<SwapchainKHRWrapper>(VkSwapchainKHR handle)
 
         for (auto image_wrapper : wrapper->child_images)
         {
-            RemoveWrapper<ImageWrapper>(image_wrapper);
-            delete image_wrapper;
+            // Destroy image if the to be destroyed swapchain is the only parent of it.
+            if (image_wrapper->parent_swapchains.size() == 1)
+            {
+                RemoveWrapper<ImageWrapper>(image_wrapper);
+                delete image_wrapper;
+            }
+            else
+            {
+                image_wrapper->parent_swapchains.erase(handle);
+            }
         }
 
         RemoveWrapper<SwapchainKHRWrapper>(wrapper);
