@@ -55,18 +55,19 @@ class VulkanStateTracker
 
     ~VulkanStateTracker();
 
-    uint64_t WriteState(util::FileOutputStream*           file_stream,
-                        util::ThreadData*                 thread_data,
-                        std::function<format::HandleId()> get_unique_id_fn,
-                        util::Compressor*                 compressor,
-                        uint64_t                          frame_number,
-                        util::FileOutputStream*           asset_file_stream,
-                        const std::string*                asset_file_name)
+    uint64_t WriteState(util::FileOutputStream*          file_stream,
+                        util::ThreadData*                thread_data,
+                        vulkan_wrappers::PFN_GetHandleId get_unique_id_fn,
+                        util::Compressor*                compressor,
+                        uint64_t                         frame_number,
+                        util::FileOutputStream*          asset_file_stream,
+                        const std::string*               asset_file_name)
     {
         VulkanStateWriter state_writer(file_stream,
                                        compressor,
                                        thread_data,
                                        get_unique_id_fn,
+                                       device_address_trackers_,
                                        asset_file_stream,
                                        asset_file_name,
                                        asset_file_stream != nullptr ? &asset_file_offsets_ : nullptr);
@@ -75,11 +76,11 @@ class VulkanStateTracker
         return state_writer.WriteState(state_table_, frame_number);
     }
 
-    uint64_t WriteAssets(util::FileOutputStream*           asset_file_stream,
-                         const std::string*                asset_file_name,
-                         util::ThreadData*                 thread_data,
-                         std::function<format::HandleId()> get_unique_id_fn,
-                         util::Compressor*                 compressor)
+    uint64_t WriteAssets(util::FileOutputStream*          asset_file_stream,
+                         const std::string*               asset_file_name,
+                         util::ThreadData*                thread_data,
+                         vulkan_wrappers::PFN_GetHandleId get_unique_id_fn,
+                         util::Compressor*                compressor)
     {
         assert(asset_file_stream != nullptr);
         assert(asset_file_name != nullptr);
@@ -88,6 +89,7 @@ class VulkanStateTracker
                                        compressor,
                                        thread_data,
                                        get_unique_id_fn,
+                                       device_address_trackers_,
                                        asset_file_stream,
                                        asset_file_name,
                                        &asset_file_offsets_);
@@ -450,6 +452,9 @@ class VulkanStateTracker
                               const uint32_t*       image_indices,
                               VkQueue               queue);
 
+    // finds potential fences in pNext-chain and tracks their usage
+    void TrackPresentFences(const VkPresentInfoKHR* present_info);
+
     void TrackAccelerationStructureKHRDeviceAddress(VkDevice                   device,
                                                     VkAccelerationStructureKHR accel_struct,
                                                     VkDeviceAddress            address);
@@ -818,7 +823,7 @@ class VulkanStateTracker
 
     void DestroyState(vulkan_wrappers::DeviceMemoryWrapper* wrapper);
 
-    void DestroyState(vulkan_wrappers::BufferWrapper* wrapper);
+    void DestroyState(vulkan_wrappers::BufferWrapper* buffer_wrapper);
 
     void DestroyState(vulkan_wrappers::AccelerationStructureKHRWrapper* wrapper);
 
