@@ -75,6 +75,16 @@ static inline void copy_dispatch_table_from_device(VkDevice device, VkCommandBuf
     *reinterpret_cast<void**>(handle) = *reinterpret_cast<void**>(device);
 }
 
+/**
+ * @brief   StripWaitSemaphores can be used to remove all wait-semaphores for a provided VkSubmitInfo.
+ *          Respective pointer in submit_info will be set to nullptr and count to zero.
+ *
+ * @param   submit_info     a provided VkSubmitInfo(2) struct
+ * @return  an array of Semaphores that have been stripped/removed from submit_info
+ */
+std::vector<std::pair<VkSemaphore, uint64_t>> StripWaitSemaphores(VkSubmitInfo* submit_info);
+std::vector<std::pair<VkSemaphore, uint64_t>> StripWaitSemaphores(VkSubmitInfo2* submit_info);
+
 [[maybe_unused]] static const char* kVulkanVrFrameDelimiterString = "vr-marker,frame_end,type,application";
 
 GFXRECON_END_NAMESPACE(graphics)
