@@ -66,10 +66,10 @@ size_t Lz4Compressor::Compress(const size_t          uncompressed_size,
     return data_size;
 }
 
-size_t Lz4Compressor::Decompress(const size_t          compressed_size,
-                                 const uint8_t*        compressed_data,
-                                 const size_t          expected_uncompressed_size,
-                                 std::vector<uint8_t>* uncompressed_data) const
+size_t Lz4Compressor::Decompress(const size_t   compressed_size,
+                                 const uint8_t* compressed_data,
+                                 const size_t   expected_uncompressed_size,
+                                 uint8_t*       uncompressed_data) const
 {
     size_t data_size = 0;
 
@@ -79,7 +79,7 @@ size_t Lz4Compressor::Decompress(const size_t          compressed_size,
     }
 
     int uncompressed_size_generated = LZ4_decompress_safe(reinterpret_cast<const char*>(compressed_data),
-                                                          reinterpret_cast<char*>(uncompressed_data->data()),
+                                                          reinterpret_cast<char*>(uncompressed_data),
                                                           static_cast<int32_t>(compressed_size),
                                                           static_cast<int32_t>(expected_uncompressed_size));
 
