@@ -76,9 +76,11 @@ const char kVersionOption[]     = "--version";
 const char kNoDebugPopup[]      = "--no-debug-popup";
 const char kExeInfoOnlyOption[] = "--exe-info-only";
 const char kEnvVarsOnlyOption[] = "--env-vars-only";
+const char kFileFormatOnlyOption[] = "--file-format-only";
 const char kEnumGpuIndices[]    = "--enum-gpu-indices";
 
-const char kOptions[] = "-h|--help,--version,--no-debug-popup,--exe-info-only,--env-vars-only,--enum-gpu-indices";
+const char kOptions[] =
+    "-h|--help,--version,--no-debug-popup,--exe-info-only,--env-vars-only,--file-format-only,--enum-gpu-indices";
 
 const char kUnrecognizedFormatString[] = "<unrecognized-format>";
 
@@ -117,11 +119,11 @@ class AnnotationRecorder : public gfxrecon::decode::AnnotationHandler
 
 struct ApiAgnosticStats
 {
-    gfxrecon::format::CompressionType      compression_type;
-    uint32_t                               trim_start_frame;
-    uint32_t                               frame_count;
-    gfxrecon::decode::FileProcessor::Error error_state;
-    bool                                   uses_frame_markers;
+    gfxrecon::format::CompressionType compression_type;
+    uint32_t                          trim_start_frame;
+    uint32_t                          frame_count;
+    gfxrecon::decode::BlockReadError  error_state;
+    bool                              uses_frame_markers;
 };
 
 std::string AdapterTypeToString(gfxrecon::format::AdapterType type)
@@ -156,6 +158,7 @@ static void PrintUsage(const char* exe_name)
     GFXRECON_WRITE_CONSOLE("  -h\t\t\tPrint usage information and exit (same as --help).");
     GFXRECON_WRITE_CONSOLE("  --version\t\tPrint version information and exit.");
     GFXRECON_WRITE_CONSOLE("  --exe-info-only\tQuickly exit after extracting captured application's executable name");
+    GFXRECON_WRITE_CONSOLE("  --file-format-only\tQuickly exit after extracting file format information");
     GFXRECON_WRITE_CONSOLE(
         "  --env-vars-only\tQuickly exit after extracting captured application's environment variables");
 #if defined(WIN32) && defined(_DEBUG)
@@ -191,7 +194,7 @@ static bool CheckOptionPrintVersion(const char* exe_name, const gfxrecon::util::
         }
 
         GFXRECON_WRITE_CONSOLE("%s version info:", app_name.c_str());
-        GFXRECON_WRITE_CONSOLE("  GFXReconstruct Version %s", GFXRECON_PROJECT_VERSION_STRING);
+        GFXRECON_WRITE_CONSOLE("  GFXReconstruct Version %s", GetProjectVersionString());
         GFXRECON_WRITE_CONSOLE("  Vulkan Header Version %u.%u.%u",
                                VK_VERSION_MAJOR(VK_HEADER_VERSION_COMPLETE),
                                VK_VERSION_MINOR(VK_HEADER_VERSION_COMPLETE),
@@ -314,6 +317,43 @@ void PrintAnnotations(uint32_t                          annotation_count,
     }
 }
 
+struct FileFormatInfo
+{
+    uint32_t major_version               = 0;
+    uint32_t minor_version               = 0;
+    bool     uses_frame_markers          = false;
+    bool     file_supports_frame_markers = false;
+
+    FileFormatInfo(const gfxrecon::decode::FileProcessor& file_processor)
+    {
+        const gfxrecon::format::FileHeader& file_header = file_processor.GetFileHeader();
+        major_version                                   = file_header.major_version;
+        minor_version                                   = file_header.minor_version;
+        uses_frame_markers                              = file_processor.UsesFrameMarkers();
+        file_supports_frame_markers                     = file_processor.FileSupportsFrameMarkers();
+    }
+
+    bool NeedsUpdate() const
+    {
+        return major_version == 0 && minor_version == 0 && uses_frame_markers && !file_supports_frame_markers;
+    }
+};
+
+void PrintFileFormatInfo(const FileFormatInfo& file_format_info)
+{
+    GFXRECON_WRITE_CONSOLE(
+        "\tFile format version: %u.%u", file_format_info.major_version, file_format_info.minor_version);
+    const char* frame_marker_type = file_format_info.uses_frame_markers
+                                        ? (file_format_info.NeedsUpdate() ? "explicit (unsupported)" : "explicit")
+                                        : "implicit";
+    GFXRECON_WRITE_CONSOLE("\tFrame delimiters: %s", frame_marker_type);
+}
+
+void PrintFileFormatInfo(const gfxrecon::decode::FileProcessor& file_processor)
+{
+    PrintFileFormatInfo(FileFormatInfo{ file_processor });
+}
+
 void PrintDriverInfo(const gfxrecon::decode::InfoConsumer& driver_info_consumer)
 {
     GFXRECON_WRITE_CONSOLE("");
@@ -372,6 +412,34 @@ void GatherAndPrintExeInfo(const std::string& input_filename)
     }
 }
 
+FileFormatInfo GatherFileFormatInfo(gfxrecon::decode::FileProcessor& file_processor,
+                                    gfxrecon::decode::InfoConsumer&  info_consumer)
+{
+    gfxrecon::decode::InfoDecoder info_decoder;
+    info_decoder.AddConsumer(&info_consumer);
+    file_processor.AddDecoder(&info_decoder);
+    bool success = file_processor.ProcessNextFrame();
+    if (success && !file_processor.UsesFrameMarkers())
+    {
+        file_processor.ProcessNextFrame();
+    }
+    return FileFormatInfo(file_processor);
+}
+
+// A short pass to get file format info. Only processes the first two frames of a capture file.
+void GatherAndPrintFileFormatInfo(const std::string& input_filename)
+{
+    const gfxrecon::decode::InfoConsumer::NoMaxBlockTag no_max_tag;
+    gfxrecon::decode::InfoConsumer                      info_consumer(no_max_tag);
+    gfxrecon::decode::FileProcessor                     file_processor;
+    if (file_processor.Initialize(input_filename))
+    {
+        FileFormatInfo file_format_info = GatherFileFormatInfo(file_processor, info_consumer);
+        GFXRECON_WRITE_CONSOLE("File format info:");
+        PrintFileFormatInfo(file_format_info);
+    }
+}
+
 #if ENABLE_OPENXR_SUPPORT
 void PrintOpenXrStats(const gfxrecon::decode::FileProcessor&       file_processor,
                       const gfxrecon::decode::OpenXrStatsConsumer& openxr_stats_consumer,
@@ -399,10 +467,11 @@ void PrintVulkanStats(const gfxrecon::decode::FileProcessor&       file_processo
                       const ApiAgnosticStats&                      api_agnostic_stats,
                       const AnnotationRecorder&                    annotation_recoder)
 {
-    if (api_agnostic_stats.error_state == gfxrecon::decode::FileProcessor::kErrorNone)
+    if (api_agnostic_stats.error_state == gfxrecon::decode::BlockReadError::kErrorNone)
     {
         GFXRECON_WRITE_CONSOLE("");
         GFXRECON_WRITE_CONSOLE("File info:");
+
         gfxrecon::format::CompressionType compression_type = gfxrecon::format::CompressionType::kNone;
 
         auto file_options = file_processor.GetFileOptions();
@@ -443,6 +512,8 @@ void PrintVulkanStats(const gfxrecon::decode::FileProcessor&       file_processo
                                    trim_start_frame + frame_count - 1);
         }
 
+        PrintFileFormatInfo(file_processor);
+
         // Application info.
         uint32_t api_version = vulkan_stats_consumer.GetApiVersion();
         GFXRECON_WRITE_CONSOLE("\nVulkan application info:");
@@ -535,7 +606,7 @@ void PrintVulkanStats(const gfxrecon::decode::FileProcessor&       file_processo
             GFXRECON_WRITE_CONSOLE("\nFile did not contain any frames");
         }
     }
-    else if (api_agnostic_stats.error_state != gfxrecon::decode::FileProcessor::kErrorNone)
+    else if (api_agnostic_stats.error_state != gfxrecon::decode::BlockReadError::kErrorNone)
     {
         GFXRECON_WRITE_CONSOLE("A failure has occurred during file processing");
         gfxrecon::util::Log::Release();
@@ -680,12 +751,13 @@ void PrintDxrEiInfo(gfxrecon::decode::Dx12StatsConsumer& dx12_consumer)
     }
 }
 
-void PrintD3D12Stats(gfxrecon::decode::Dx12StatsConsumer& dx12_consumer,
+void PrintD3D12Stats(gfxrecon::decode::FileProcessor&     file_processor,
+                     gfxrecon::decode::Dx12StatsConsumer& dx12_consumer,
                      const ApiAgnosticStats&              api_agnostic_stats,
                      gfxrecon::decode::InfoConsumer&      info_consumer,
                      const AnnotationRecorder&            annotation_recoder)
 {
-    if (api_agnostic_stats.error_state == gfxrecon::decode::FileProcessor::kErrorNone)
+    if (api_agnostic_stats.error_state == gfxrecon::decode::BlockReadError::kErrorNone)
     {
         GFXRECON_WRITE_CONSOLE("");
         GFXRECON_WRITE_CONSOLE("File info:");
@@ -724,6 +796,8 @@ void PrintD3D12Stats(gfxrecon::decode::Dx12StatsConsumer& dx12_consumer,
             GFXRECON_WRITE_CONSOLE("\tTest present count: %u", dx12_consumer.GetDXGITestPresentCount());
         }
 
+        PrintFileFormatInfo(file_processor);
+
         PrintDriverInfo(info_consumer);
 
         PrintDx12RuntimeInfo(dx12_consumer);
@@ -734,7 +808,7 @@ void PrintD3D12Stats(gfxrecon::decode::Dx12StatsConsumer& dx12_consumer,
 
         PrintDxrEiInfo(dx12_consumer);
     }
-    else if (api_agnostic_stats.error_state != gfxrecon::decode::FileProcessor::kErrorNone)
+    else if (api_agnostic_stats.error_state != gfxrecon::decode::BlockReadError::kErrorNone)
     {
         GFXRECON_WRITE_CONSOLE("A failure has occurred during file processing");
         gfxrecon::util::Log::Release();
@@ -811,7 +885,7 @@ void GatherAndPrintEnvVars(const std::string& input_filename)
         info_decoder.AddConsumer(&info_consumer);
         file_processor.AddDecoder(&info_decoder);
         file_processor.ProcessAllFrames();
-        if (file_processor.GetErrorState() == gfxrecon::decode::FileProcessor::kErrorNone)
+        if (file_processor.GetErrorState() == gfxrecon::decode::BlockReadError::kErrorNone)
         {
             PrintEnvironmentVariableInfo(info_consumer);
         }
@@ -868,7 +942,7 @@ void GatherAndPrintAllInfo(const std::string& input_filename)
 #endif
 
         file_processor.ProcessAllFrames();
-        if (file_processor.GetErrorState() == gfxrecon::decode::FileProcessor::kErrorNone)
+        if (file_processor.GetErrorState() == gfxrecon::decode::BlockReadError::kErrorNone)
         {
             ApiAgnosticStats api_agnostic_stats = {};
             GatherApiAgnosticStats(api_agnostic_stats, file_processor, stat_consumer);
@@ -907,7 +981,7 @@ void GatherAndPrintAllInfo(const std::string& input_filename)
 #if defined(D3D12_SUPPORT)
             if (dx12_detection_consumer.WasD3D12APIDetected() || print_all_apis)
             {
-                PrintD3D12Stats(dx12_consumer, api_agnostic_stats, info_consumer, annotation_recorder);
+                PrintD3D12Stats(file_processor, dx12_consumer, api_agnostic_stats, info_consumer, annotation_recorder);
             }
 #endif
 #if ENABLE_OPENXR_SUPPORT
@@ -973,6 +1047,10 @@ int main(int argc, const char** argv)
     {
         GatherAndPrintEnvVars(input_filename);
     }
+    else if (arg_parser.IsOptionSet(kFileFormatOnlyOption))
+    {
+        GatherAndPrintFileFormatInfo(input_filename);
+    }
     else
     {
         GatherAndPrintAllInfo(input_filename);
